@@ -1,7 +1,5 @@
 package App::Git::Info;
-$App::Git::Info::VERSION = '0.6.0';
-# ABSTRACT: Displays a summary of information about the git repository.
-
+$App::Git::Info::VERSION = '0.6.1';
 use strict;
 use warnings;
 use 5.016;
@@ -17,25 +15,27 @@ __END__
 
 =head1 NAME
 
+App::Git::Info - Displays a summary of information about the git repository.
+
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 SYNOPSIS
 
-    shlomif@telaviv1:~/conf/trunk$ git info info
+    shlomif[perl-begin]:$trunk$ git info info
     ⇒ On branch master
-     M shlomif-settings/home-bin-executables/bin/git-i
+    ⇒ Your branch is up to date with 'origin/master'.
+    ?? y.txt
     ⇒ Remotes:
-    origin  git@github.com:shlomif/shlomif-computer-settings.git (fetch)
-    origin  git@github.com:shlomif/shlomif-computer-settings.git (push)
-    shlomif@telaviv1:~/conf/trunk$
+    origin  git@github.com:shlomif/perl-begin.git (fetch)
+    origin  git@github.com:shlomif/perl-begin.git (push)
+    shlomif[perl-begin]:$trunk$
 
-=head1 METHODS
+=head1 DESCRIPTION
 
-=head2 info
-
-Implement the info subcommand.
+Displays a git dashboard-of-sorts with info from C<git status>,
+C<git status -s>, and C<git remote -v> .
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
